@@ -39,18 +39,24 @@ QString AppPackageKitResource::name()
 
 QString AppPackageKitResource::longDescription()
 {
-    return m_appdata.description();
+    const auto desc = m_appdata.description();
+    if (!desc.isEmpty())
+        return desc;
+
+    return PackageKitResource::longDescription();
 }
 
 QString AppPackageKitResource::icon() const
 {
-    QString anIcon = m_appdata.icon();
-    if (anIcon.isEmpty()) {
-        QUrl iconUrl = m_appdata.iconUrl(QSize());
-        if (iconUrl.isLocalFile())
-            anIcon = iconUrl.toLocalFile();
-    }
-    return anIcon;
+    const QString anIcon = m_appdata.icon();
+    if (!anIcon.isEmpty())
+        return anIcon;
+
+    const QUrl iconUrl = m_appdata.iconUrl(QSize());
+    if (iconUrl.isLocalFile())
+        return iconUrl.toLocalFile();
+
+    return QStringLiteral("applications-other");
 }
 
 QString AppPackageKitResource::license()
@@ -70,7 +76,11 @@ QStringList AppPackageKitResource::categories()
 
 QString AppPackageKitResource::comment()
 {
-    return m_appdata.summary();
+    const auto summary = m_appdata.summary();
+    if (!summary.isEmpty())
+        return summary;
+
+    return PackageKitResource::comment();
 }
 
 QString AppPackageKitResource::appstreamId() const
